Learn R Programming

VC2copula (version 0.1.2)

VC2copula-package: VC2copula: Extend the 'copula' Package with Families and Models from 'VineCopula'

Description

Provides new classes for (rotated) BB1, BB6, BB7, BB8, and Tawn copulas, extends the existing Gumbel and Clayton families with rotations, and allows to set up a vine copula model using the 'copula' API. Corresponding objects from the 'VineCopula' API can easily be converted.

Arguments

See Also

Useful links: