powered by
S4-class representation of the Tawn Copula family of type 2 and rotated versions there of.
Objects can be created by calls of the form new("tawnT2Copula", ...), or through the explicit constructors tawnT2Copula(), surTawnT2Copula(), r90TawnT2Copula() and r270TawnT2Copula() respectively.
new("tawnT2Copula", ...)
tawnT2Copula()
surTawnT2Copula()
r90TawnT2Copula()
r270TawnT2Copula()
'>tawnT2Copula and the package VineCopula-package() for implementation details.
VineCopula-package()
# NOT RUN { showClass("tawnT2Copula") # }
Run the code above in your browser using DataLab